@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.3.3';
+our $VERSION = '0.3.4';
 
 1;
 
@@ -200,10 +200,18 @@ sub populate_config {
             push @cli_args, $item;
           } elsif(ref $item eq 'HASH'){
             for my $k ( keys %{$item}){
-              push @cli_args, '--'.$k, $item->{$k};
+              my $k1 = $k;
+              if ($k1=~s/^~//){
+                push @cli_args, '-'.$k1, $item->{$k};
+              }else{
+                push @cli_args, '--'.$k1, $item->{$k};
+              }
             }
           } elsif(ref $item eq 'ARRAY'){
-            push @cli_args, map {'--'.$_ } @{$item};
+            push @cli_args, map {
+              my $v = $_;
+              $v=~s/^~// ? '-'.$v : '--'.$v;
+            } @{$item};
           };
         }
         note("cli args set to: ".(join ' ', @cli_args)) if debug_mod12;
@@ -1607,6 +1615,110 @@ Runtime configuration parameters override ones in suite configuration. Consider
     $ strun --param foo.bar=20 # will override foo.bar parameter to 20
 
 
+=head1 Free style command line parameters
+
+Alternative way to pass input parameters into outthentic scripts is a I<free style> command line arguments:
+
+    $ strun -- <arguments>
+
+Consider a simple example. We want to create a wrapper for some external script which accepts the following 
+command line arguments:
+
+    script {flags} {named parameters} {value} 
+
+Where flags are:
+
+    --verbose
+    --debug
+
+Named parameters are:
+
+    --foo foo-value
+    --var bar-value
+
+And value is just a string:
+
+    foo-value
+
+It's quite demanding to map external script parameters into Outthentic configuration. More over 
+some parameters of external scripts are optional. 
+
+Here is free style command line arguments to the rescue:
+
+    $ nano story.bash
+    script $(args_cli)        
+
+That's all. Now we are safe to run our story-wrapper with command line arguments I<in terms of> external script:
+
+    $ strun -- --foo foo-value --debug the-value
+
+
+=head1 Auto coercion of configuration data into free style command line parameters
+
+Moreover it's possible declare external script parameters in suite configuration:
+
+    $ nano suite.yaml
+    
+      ---
+    
+      args:
+        - foo: foo-value
+        -
+          - debug 
+          - verbose 
+        - the-value
+    
+    $ strun
+
+This is end up in running story with following command line arguments for external script:
+
+    --foo foo-value --debug --verbose the-value
+
+
+=head1 Auto coercion rules
+
+=over
+
+=item *
+
+Args should be array which elements are processed in order, for every elements rules are applied depending on element's type
+
+
+=item *
+
+Scalars are turned into scalars: C<<< the-value ---> the-value >>>
+
+
+=item *
+
+Arrays are turned into scalars with double dashes perpended: C<<< (debug, verbose) ---> --debug --verbose >>>. This is useful for declaring
+boolean flags 
+
+
+=item *
+
+Hashes are turned into named parameters: C<<< foo: foo-value ---> --foo foo-value >>>
+
+
+=back
+
+
+=head1 Auto coercion, using single dashes instead of double dashes
+
+Double dashes are default behavior of how named parameters and flags 
+converted. If you need single dashes, prepend parameters in configuration file with C<~> :
+
+    $ nano suite.yaml
+    
+      ---
+    
+      args:
+        - '~foo': foo-value
+        -
+          - ~debug 
+          - ~verbose 
+
+
 =head1 Environment variables
 
 =over
@@ -1662,13 +1774,13 @@ Where C<$story-name> is any top level directory inside examples/.
 
 =item *
 
-Brief introduction of check file syntax could be found here - https://github.com/melezhik/outthentic/blob/master/check-files-syntax.md
+Brief introduction of check file syntax could be found here - L<https://github.com/melezhik/outthentic/blob/master/check-files-syntax.md|https://github.com/melezhik/outthentic/blob/master/check-files-syntax.md>
 
 
 
 =item *
 
-For the full detailed explanation follow Outthentic::DSL doc pages at https://github.com/melezhik/outthentic-dsl
+For the full detailed explanation follow Outthentic::DSL doc pages at L<https://github.com/melezhik/outthentic-dsl|https://github.com/melezhik/outthentic-dsl>
 
 
 
